# Proceso de release

1. Cambiar el número de versión en `setup.py`.

2. Generar el paquete:

```bash
sudo apt install python3-build
python3 -m build
```

3. Instalar twine:

```bash
pip3 install twine
```

Este paso puede variar dependiendo la versión de Ubuntu utilizada (ver más abajo cómo setear el entorno virtual).

4. Subirlo a pypi:

```bash
twine upload dist/*
```

Pasar el API TOKEN.

5. Borrar los archivos del build:

```bash
rm -rf dist/ build/ tbbackoff.egg-info/
```

# Tests

1. Configurar un entorno virtrual:

```bash
python3 -m venv venv
source venv/bin/activate
pip3 install mock twine  # TODO: armar un requirements.txt
pip3 install -e .
```

2. Ejecutar los tests:

```bash
python -m unittest
```